#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2022 AioCrypto

__author__ = "ErVinTract"
__description__ = "Async Crypto API for humans"

__github__ = "https://github.com/ErVinTract/AioCrypto"

__version__ = '1.0.6'
__release__ = '1.1b'


from .errors import *
from .types import *
from .app import *
